Class: OptionParser::MissingOption

Inherits:
ParseError
  • Object
show all
Defined in:
lib/ref_arch_setup/cli.rb

Overview

Adds an exception for missing a required option

OptionParser doesn’t handle required options, only required arguments to the options And even that it doesn’t do all that well. This creates a missing argument exception for use by this CLI class

Author:

  • Randell Pelak